
# octopwnremote
Python library for remotely control OctoPwn.

## Install
`pip install octopwnremote`
After install you will have `octopwn-remote-client` `octopwn-remote-proxy` and `octopwn-remote-server` commands. The latter is only useful to verify incoming connections, otherwise you will have to write code, see `proxy.py` as example.

## Example
Example file with basic usage of this library can be found in the example.

